@@ -11,7 +11,7 @@ test_that("bisonmap returns the correct class", {
   
   expect_is(map1, "gg")
   expect_is(map1$data, "data.frame")
-  expect_is(map1$scales, "refClass")
+  expect_is(map1$scales, "ScalesList")
   expect_is(map2, "gg")
   expect_is(map3, "gg")
 })
